@@ -50,29 +50,29 @@ extern unsigned char packet_header[4];
 extern struct neighbour *unicast_neighbour;
 extern struct timeval unicast_flush_timeout;
 
-void parse_packet(const unsigned char *from, struct network *net,
+void parse_packet(const unsigned char *from, struct interface *ifp,
                   const unsigned char *packet, int packetlen);
-void flushbuf(struct network *net);
-void flushupdates(struct network *net);
+void flushbuf(struct interface *ifp);
+void flushupdates(struct interface *ifp);
 void send_ack(struct neighbour *neigh, unsigned short nonce,
               unsigned short interval);
-void send_hello_noupdate(struct network *net, unsigned interval);
-void send_hello(struct network *net);
+void send_hello_noupdate(struct interface *ifp, unsigned interval);
+void send_hello(struct interface *ifp);
 void flush_unicast(int dofree);
-void send_update(struct network *net, int urgent,
+void send_update(struct interface *ifp, int urgent,
                  const unsigned char *prefix, unsigned char plen);
-void send_update_resend(struct network *net,
+void send_update_resend(struct interface *ifp,
                         const unsigned char *prefix, unsigned char plen);
-void send_wildcard_retraction(struct network *net);
+void send_wildcard_retraction(struct interface *ifp);
 void update_myseqno(void);
-void send_self_update(struct network *net);
-void send_ihu(struct neighbour *neigh, struct network *net);
-void send_marginal_ihu(struct network *net);
-void send_request(struct network *net,
+void send_self_update(struct interface *ifp);
+void send_ihu(struct neighbour *neigh, struct interface *ifp);
+void send_marginal_ihu(struct interface *ifp);
+void send_request(struct interface *ifp,
                   const unsigned char *prefix, unsigned char plen);
 void send_unicast_request(struct neighbour *neigh,
                           const unsigned char *prefix, unsigned char plen);
-void send_multihop_request(struct network *net,
+void send_multihop_request(struct interface *ifp,
                            const unsigned char *prefix, unsigned char plen,
                            unsigned short seqno, const unsigned char *id,
                            unsigned short hop_count);
